package com.ether;

import org.jetbrains.annotations.NotNull;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpSession;
import java.util.Calendar;
import java.util.Locale;

public class Context
{
    /**
     * Return the current Locale
     *
     * @param request
     * @return
     */
    public static Locale getLocale( @NotNull final HttpServletRequest request )
    {
        final HttpSession session = request.getSession( true );
        Locale locale = (Locale) session.getAttribute( "LOCALE" );
        if( locale == null )
            locale = request.getLocale();

        if( request.getParameter( "language" ) != null )
            locale = new Locale( request.getParameter( "language" ) );

        return locale;
    }

    /**
     * Indicates if the locale is french
     *
     * @param request
     * @return
     */
    public static boolean isFrench( @NotNull final HttpServletRequest request )
    {
        final Locale locale = getLocale( request );
        return locale.getLanguage().equals( "fr" );
    }

    /**
     * Permet d'obtenir la date courante, sous la forme YYYYMMDD
     *
     * @return la date courante
     */
    public static String getSimpleDate()
    {
        Calendar c = Calendar.getInstance();
        String t = "0" + ( c.get( Calendar.MONTH ) + 1 );
        return c.get( Calendar.YEAR ) + t.substring( t.length() - 2 ) + c.get( Calendar.DAY_OF_MONTH );
    }

    /**
     * Désigne l'adresse mail du webmaster
     */
    public static String getWebmaster( final HttpServletRequest request )
    {
        return (String) request.getSession().getServletContext().getAttribute( "APP_WEBMASTER" );
    }

    /**
     * Permet de définir le nom de la racine à partir de laquelle les paths sont calculés.
     *
     * @return le nom de la racine.
     */
    public static String getWebroot( final HttpServletRequest request )
    {
        final String path = request.getSession().getServletContext().getRealPath( "" );
        return path.substring( path.lastIndexOf( "/" ) + 1 );
    }

    /**
     * Permet d'obtenir l'uri de la page courante.
     *
     * @param request : la requête courante
     * @return l'uri de la page courante
     */
    public static String getPageURI( final HttpServletRequest request )
    {
        return request.getRequestURI().substring( request.getRequestURI().indexOf( '/' ) + 1 );
    }

    /**
     * Permet d'obtenir l'URI relative de la page courante.
     * Cette méthode est en particulier utilisée pour retomber sur la page courante lorsqu'on
     * change de langue.
     *
     * @param request
     * @return
     */
    public static String getRelativePageURI( final HttpServletRequest request )
    {
        String pageUri = getPageURI( request );
        if( pageUri.indexOf( '/' ) != -1 )
        {
            pageUri = pageUri.substring( pageUri.indexOf( '/' ) );
        }
        return pageUri;
    }


    public static String getRelativePath( final HttpServletRequest request )
    {
        String uri = getPageURI( request );
        if( uri.indexOf( '/' ) != -1 )
        {
            uri = uri.substring( uri.indexOf( '/' ), uri.lastIndexOf( '/' ) );
        }
        return uri;
    }

    /**
     * Permet d'obtenir la langue courante.
     *
     * @param request : la requête courante
     * @return la langue courante.
     */
    public static String getLangue( final HttpServletRequest request )
    {
        String lang = (String) request.getSession().getAttribute( "lang" );
        if( lang == null )
        {
            // Pour initialiser la langue en Anglais
            lang = request.getLocale().getLanguage();

            // Pour initialiser la langue en Français
            //lang = Locale.FRENCH.getLanguage();
        }
        return lang;
    }

}
